@@ -22,6 +22,7 @@
 *  along with GLPK. If not, see <http://www.gnu.org/licenses/>.
 ***********************************************************************/
 
+#include "env.h"
 #include "glpios.h"
 
 /***********************************************************************
@@ -135,7 +136,7 @@ static int best_node(glp_tree *T)
             for (node = T->head; node != NULL; node = node->next)
                if (bound > node->bound) bound = node->bound;
             xassert(bound != +DBL_MAX);
-            eps = 0.001 * (1.0 + fabs(bound));
+            eps = 1e-10 * (1.0 + fabs(bound));
             for (node = T->head; node != NULL; node = node->next)
             {  if (node->bound <= bound + eps)
                {  xassert(node->up != NULL);
@@ -153,7 +154,7 @@ static int best_node(glp_tree *T)
             for (node = T->head; node != NULL; node = node->next)
                if (bound < node->bound) bound = node->bound;
             xassert(bound != -DBL_MAX);
-            eps = 0.001 * (1.0 + fabs(bound));
+            eps = 1e-10 * (1.0 + fabs(bound));
             for (node = T->head; node != NULL; node = node->next)
             {  if (node->bound >= bound - eps)
                {  xassert(node->up != NULL);
