@@ -4,9 +4,9 @@
 *  This code is part of GLPK (GNU Linear Programming Kit).
 *
 *  Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008,
-*  2009, 2010, 2011, 2013, 2014, 2015 Andrew Makhorin, Department for
-*  Applied Informatics, Moscow Aviation Institute, Moscow, Russia. All
-*  rights reserved. E-mail: <mao@gnu.org>.
+*  2009, 2010, 2011, 2013, 2014, 2015, 2016 Andrew Makhorin, Department
+*  for Applied Informatics, Moscow Aviation Institute, Moscow, Russia.
+*  All rights reserved. E-mail: <mao@gnu.org>.
 *
 *  GLPK is free software: you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License as published by
@@ -34,7 +34,7 @@ extern "C" {
 
 /* library version numbers: */
 #define GLP_MAJOR_VERSION  4
-#define GLP_MINOR_VERSION  57
+#define GLP_MINOR_VERSION  58
 
 typedef struct glp_prob glp_prob;
 /* LP/MIP problem object */
@@ -751,6 +751,9 @@ int glp_write_prob(glp_prob *P, int flags, const char *fname);
 glp_tran *glp_mpl_alloc_wksp(void);
 /* allocate the MathProg translator workspace */
 
+void glp_mpl_init_rand(glp_tran *tran, int seed);
+/* initialize pseudo-random number generator */
+
 int glp_mpl_read_model(glp_tran *tran, const char *fname, int skip);
 /* read and translate model section */
 
@@ -769,9 +772,6 @@ int glp_mpl_postsolve(glp_tran *tran, glp_prob *prob, int sol);
 void glp_mpl_free_wksp(glp_tran *tran);
 /* free the MathProg translator workspace */
 
-int glp_main(int argc, const char *argv[]);
-/* stand-alone LP/MIP solver */
-
 int glp_read_cnfsat(glp_prob *P, const char *fname);
 /* read CNF-SAT problem data in DIMACS format */
 
@@ -861,6 +861,12 @@ void glp_mem_usage(int *count, int *cpeak, size_t *total,
       size_t *tpeak);
 /* get memory usage information */
 
+double glp_time(void);
+/* determine current universal time */
+
+double glp_difftime(double t1, double t0);
+/* compute difference between two time values */
+
 typedef struct glp_graph glp_graph;
 typedef struct glp_vertex glp_vertex;
 typedef struct glp_arc glp_arc;
